@@ -44,7 +44,7 @@ def generate_patt(filename, output=None, string=False):
             color_to_file(r, patt)
             color_to_file(g, patt)
             color_to_file(b, patt)
-            if(i != 3):
+            if i != 3:
                 patt.write("\n")
             image = image.rotate(90)
 
@@ -52,6 +52,7 @@ def generate_patt(filename, output=None, string=False):
     else:
         raise FileNotFoundError
 
+
 def patt_number_format(point):
     return str(point).rjust(3, " ")
 
@@ -83,4 +84,4 @@ def generate_marker(filename, border_percentage=50, output=None):
         marker.paste(image, get_box_coords(image, border_size))
         marker.save(output + name + "_marker.png", "PNG")
     else:
-        raise FileNotFoundError
\ No newline at end of file
+        raise FileNotFoundError
